@@ -1,5 +1,5 @@
 /* This file is part of GNU Rush.                  
-   Copyright (C) 2008, 2009 Sergey Poznyakoff
+   Copyright (C) 2008, 2009, 2010 Sergey Poznyakoff
 
    GNU Rush is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -322,8 +322,6 @@ run_tests(struct rush_rule *rule, struct rush_request *req)
 struct rush_rule *
 match_rule(struct rush_rule *rule, struct rush_request *req)
 {
-        if (!rule)
-                rule = rule_head;
         for (; rule; rule = rule->next) {
                 if (run_tests(rule, req) == 0)
                         break;
@@ -335,7 +333,7 @@ char *
 make_file_name(const char *dir, const char *name)
 {
 	size_t dlen = strlen(dir);
-	size_t len = dlen + strlen(name + 1);
+	size_t len = dlen + strlen(name) + 1;
 	char *res = xmalloc(len + 1);
 	strcpy(res, dir);
 	if (dlen > 0 && res[dlen-1] != '/')
@@ -585,6 +583,7 @@ run_transforms(struct rush_rule *rule, struct rush_request *req)
                         break;
 
 		case transform_setcmd:
+			GET_TGT_VAL();
 			if (args_transformed) {
                                 rebuild_cmdline(req);
                                 args_transformed = 0;
@@ -835,14 +834,11 @@ run_rule(struct rush_rule *rule, struct rush_request *req)
         if (rule->fall_through)
                 return;
 
-	if (req->acct) {
-		mode_t um = umask(022);
-		if (rushdb_open(RUSH_DB, 1) != rushdb_result_ok) 
-			die(system_error, &req->i18n, 
-			    _("cannot open database %s: %s"),
-			    RUSH_DB, rushdb_error_string);
-		umask(um);
-	}
+	if (req->acct == rush_true &&
+	    rushdb_open(RUSH_DB, 1) != rushdb_result_ok) 
+		die(system_error, &req->i18n, 
+		    _("cannot open database %s: %s"),
+		    RUSH_DB, rushdb_error_string);
 	
 	if (req->chroot_dir && chroot(req->chroot_dir)) 
 		die(system_error, &req->i18n, _("cannot chroot to %s: %s"),
@@ -957,19 +953,19 @@ main(int argc, char **argv)
                 die(system_error, NULL,
                     _("argcv_get(%s) failed: %s"),
                     req.cmdline, strerror(rc));
-        
-        for (rule = NULL; ; rule = rule->next) {
+
+	for (rule = rule_head; rule; rule = rule->next) {
                 rule = match_rule(rule, &req);
                 if (!rule)
-                        die(usage_error, &req.i18n, 
-                            _("no matching rule for \"%s\", user %s"),
-                            req.cmdline, req.pw->pw_name);
+                        break;
                 if (debug_level) 
                         logmsg(LOG_NOTICE,
                                _("Serving request \"%s\" for %s by rule %s"),
                                command, req.pw->pw_name, rule->tag);
                 run_rule(rule, &req);
-        } 
-        
+        }
+	die(usage_error, &req.i18n, 
+	    _("no matching rule for \"%s\", user %s"),
+	    req.cmdline, req.pw->pw_name);        
         return 0;
 }
