@@ -1,5 +1,5 @@
 /* This file is part of GNU Rush.                  
-   Copyright (C) 2008, 2009 Sergey Poznyakoff
+   Copyright (C) 2008, 2009, 2010 Sergey Poznyakoff
 
    GNU Rush is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/time.h>
 #include <sys/wait.h>
 #include <sys/resource.h>
 #include <syslog.h>
@@ -69,6 +70,10 @@
 # define getmaxfd() 256
 #endif
 
+#ifndef LOG_AUTHPRIV
+# define LOG_AUTHPRIV LOG_AUTH
+#endif
+
 #define ISWS(c) ((c) == ' ' || (c) == '\t')
 
 enum error_type {
@@ -291,7 +296,7 @@ void parse_config(void);
 void set_error_msg(enum error_type type, char *text);
 int string_to_error_index(const char *name);
 
-transform_t compile_transform_expr (const char *expr);
+transform_t compile_transform_expr (const char *expr, int cflags);
 char *transform_string (struct transform *tf, const char *input);
 
 int post_socket_send(const struct rush_sockaddr *sockaddr,
